Detection
=========

Detectors
---------

.. python-apigen-group:: detection-detectors

Theoretical performance
-----------------------

.. python-apigen-group:: detection-theory

Approximated performance
------------------------

.. python-apigen-group:: detection-approximation

Coherent integration
--------------------

.. python-apigen-group:: detection-coherent-integration

Non-coherent integration
------------------------

.. python-apigen-group:: detection-non-coherent-integration
